@@ -70,7 +70,7 @@ our(%name2bom) =
 	'UTF-8'     => "\xef\xbb\xbf",
 );
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 # ------------------------------------------------
 
@@ -87,7 +87,7 @@ sub add
 
 	die "Unknown BOM name: $name\n" if (! $name2bom{$name});
 
-	write_text($output_file, $name2bom{$name} . ${self -> data}, $name2bom{$name});
+	write_binary($output_file, $name2bom{$name} . ${$self -> data});
 
 	# Return 0 for success and 1 for failure.
 
@@ -198,7 +198,7 @@ sub remove
 
 	substr(${$self -> data}, 0, $$result{length}) = '';
 
-	write_file($output_file, {binmode => ':raw'}, ${$self -> data});
+	write_binary($output_file, ${$self -> data});
 
 	# Return 0 for success and 1 for failure.
 
@@ -685,7 +685,7 @@ C<%opt> may contain these (key => value) pairs:
 
 =head2 How does this module read and write files?
 
-It uses L<File::Slurp>.
+It uses L<File::Slurper>'s read_binary() and write_binary().
 
 =head2 What are the hashes accessible from outside the module?
 
@@ -711,11 +711,17 @@ For instance, if you call:
 Then the code calls C<action('test')>, which sets the 'current' value of C<action> to C<test>.
 
 This means that if you later call C<action()>, the value returned is whatever was the most recent
-value provided (to any method) in C<$opt{action}>. Similarly for the other parameters to L</new([%opt])>.
+value provided (to any method) in C<$opt{action}>. Similarly for the other parameters to
+L</new([%opt])>.
 
 Note: As syntactic sugar, you may specify just the 1st letter of the action. And that's why
 C<test> is called C<test> and not C<report>.
 
+=head2 What happens if I add the same BOM twice?
+
+The program will do as you order it to do. Hopefully, you remove one or both of the BOMs immediately
+after testing the output.
+
 =head1 See Also
 
 L<String::BOM>.
@@ -726,6 +732,8 @@ L<File::BOM>.
 
 L<XML::Tiny>, whose test data I've adopted.
 
+L<File::Slurper>.
+
 =head1 Machine-Readable Change Log
 
 The file Changes was converted into Changelog.ini by L<Module::Metadata::Changes>.
